==> grantlee-editor-16.11.90.tar.xz: grantlee-editor-16.11.90/grantleethemeeditor/grantleeplaintexteditor.h <==
/*
   Copyright (C) 2013-2016 Montel Laurent <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/
#ifndef GRANTLEEPLAINTEXTEDITOR_H
#define GRANTLEEPLAINTEXTEDITOR_H

#include "kpimtextedit/plaintexteditor.h"
#include "config-grantleethemeeditor.h"
#include <KSyntaxHighlighting/Repository>

namespace KPIMTextEdit
{
class TextEditorCompleter;
}
namespace GrantleeThemeEditor
{
class GrantleePlainTextEditor : public KPIMTextEdit::PlainTextEditor
{
    Q_OBJECT
public:
    explicit GrantleePlainTextEditor(QWidget *parent = Q_NULLPTR);
    ~GrantleePlainTextEditor();

    void createCompleterList(const QStringList &extraCompletion);

protected:
    void keyPressEvent(QKeyEvent *e) Q_DECL_OVERRIDE;

protected:
    KPIMTextEdit::TextEditorCompleter *mTextEditorCompleter;
private:
    void initCompleter();
    KSyntaxHighlighting::Repository mRepo;
};
}

#endif // GRANTLEEPLAINTEXTEDITOR_H

==> grantlee-editor-17.03.80.tar.xz: grantlee-editor-17.03.80/grantleethemeeditor/grantleeplaintexteditor.h <==
/*
   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/
#ifndef GRANTLEEPLAINTEXTEDITOR_H
#define GRANTLEEPLAINTEXTEDITOR_H

#include "kpimtextedit/plaintexteditor.h"
#include "config-grantleethemeeditor.h"
#include <KSyntaxHighlighting/Repository>

namespace KPIMTextEdit
{
class TextEditorCompleter;
}
namespace GrantleeThemeEditor
{
class GrantleePlainTextEditor : public KPIMTextEdit::PlainTextEditor
{
    Q_OBJECT
public:
    explicit GrantleePlainTextEditor(QWidget *parent = nullptr);
    ~GrantleePlainTextEditor();

    void createCompleterList(const QStringList &extraCompletion);

protected:
    void keyPressEvent(QKeyEvent *e) Q_DECL_OVERRIDE;

protected:
    KPIMTextEdit::TextEditorCompleter *mTextEditorCompleter;
private:
    void initCompleter();
    KSyntaxHighlighting::Repository mRepo;
};
}

#endif // GRANTLEEPLAINTEXTEDITOR_H
